
#INPUT FILES:

#Ix/USPHe_EMOL_Ix_K-1_1.dat : contains 3 columns, time [in attosecon], Energy of the molecule [in hartree], deposited energy [in eV]
#Ix/xUSPHe_QFDiff_Ix_K-1_1_FR1_54.dat: contains 56 columns, time [in attosecon], charge of each of the 54 molecular fragments composing the QM region. (Phosphate, ribose, base, 51 water molecules)
#Ix cooresponds to each of the five collision trajectories described in the article 1=CU1, 2=CU2, 3=CS, 4=CP and 5=CW

#OUTPUT FILES:
#FigureS1right.tiff Image of the deposition energy profile (Figure S1)
#Figure4a-e.tiff, Image of charge fluctuations (Figure 4) 

#VARIABLES:
#nrj: vector containing the values of energy deposited as a function of time
#qf: Array containing for each column the fragment charge as a function of time
#time, time2: vector containing the time along the series.


#CONVERSION FACTORS
ua2D=2.54174629656520
ev2cm1=8065.73
ev2ha=0.0367502
kcalmol2ua=0.00159362
kcalmol2ev=0.0433634
fs2at=41.34137335
ha2cm=219474.63
j2eV=6.24181e18
bohr=5.2917721092*1E-11
uatps=2.418884326505*1E-17

# CONSTANTS  
kb=1.3806488e-23
temp=298.
hbar=1.054571726E-34
kbTeV=kb*temp*j2eV
kbTha=kbTeV*ev2ha
clum=299792458*uatps/bohr


####################### PLOT ENERGY DEPOSITION PROFILES ####################

time2<-c()
nrj<-c()
temp <- data.frame(read.table(file='I1/USPEl_EMOL_I1_K5-5_1.dat',header=FALSE))
time2 <- cbind(time2,temp[,1]/1000)
nrj<- cbind(nrj,temp[,3])
temp <- data.frame(read.table(file='I2/USPEl_EMOL_I2_K5-5_1.dat',header=FALSE))
nrj<- cbind(nrj,temp[,3])
temp <- data.frame(read.table(file='I3/USPEl_EMOL_I3_K5-5_1.dat',header=FALSE))
nrj<- cbind(nrj,temp[,3])
temp <- data.frame(read.table(file='I4/USPEl_EMOL_I4_K5-5_1.dat',header=FALSE))
nrj<- cbind(nrj,temp[,3])
temp <- data.frame(read.table(file='I5/USPEl_EMOL_I5_K5-5_1.dat',header=FALSE))
nrj<- cbind(nrj,temp[,3])


png(filename = "FigureS1right.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


xmin=1
xmax=7
ymax=max(nrj)
ymin=min(nrj)
par(mar=c(5.5,5.5,2,2))

plot(time2[,1],nrj[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="",main = "50 eV electron")
lines(time2[,1],nrj[,2],type='l',lwd=5,col="red")
lines(time2[,1],nrj[,3],type='l',lwd=5,col="blue")
lines(time2[,1],nrj[,4],type='l',lwd=5,col="forestgreen")
lines(time2[,1],nrj[,5],type='l',lwd=5,col="darkorchid4")
axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(0,ymax+60,60),pos=xmin,cex.axis=1.5,lwd=2,las=1)

title(xlab="Time (fs)", 
      ylab="deposited energy (eV)",cex.lab=1.75,line=4)

dev.off()

############################# PLOT CHARGE FLUCTUATIONS I1 = CU1 ###############################""
# Read data
time<-c()
qf<-c()
temp <- data.frame(read.table(file='I1/USPEl_QFDiff_I1_K5-5_1_FR1_54.dat',header=FALSE))
qf<- cbind(qf,temp[,2])
qf<- cbind(qf,temp[,3])
qf<- cbind(qf,temp[,4])
qf<- cbind(qf,temp[,5])
time <- cbind(time,temp[,1]/1000)

# Sum charges of all water molecules, collect in column 4
for (I in seq(5,54,1)) {
  for (j in seq(1,length(qf[,4]),1)) {
    qf[j,4] = qf[j,4] + temp[j,I+1]
  } 
}

# Make plot and save the file
png(filename = "Figure4a.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


ymax=0.5
ymin=-0.5
qfmax=max(qf)
qfmin=min(qf)
xmin=1
xmax=7
par(mar=c(4,5.5,1,2))
plot(time[,1],qf[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="")
lines(time[,1],qf[,2],type='l',lwd=5,col="red")
lines(time[,1],qf[,3],type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,4],type='l',lwd=5,col="blue")
lines(time[,1],qf[,2]+qf[,3],lty=2,type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,1]+qf[,2]+qf[,3]+qf[,4],lty=2,type='l',lwd=5,col="black")

axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
text(x=5.0,y=0.5*ymin,bquote("CU1, 50 eV electron"),cex=1.75)
title(xlab="Time (fs)", cex.lab=1.75,line=2)
title(ylab="charge variation (a.u.)",cex.lab=1.75,line=4)

dev.off()

############################# PLOT CHARGE FLUCTUATIONS I2 = CU2 ###############################
# Read data
time<-c()
qf<-c()
temp <- data.frame(read.table(file='I2/USPEl_QFDiff_I2_K5-5_1_FR1_54.dat',header=FALSE))
qf<- cbind(qf,temp[,2])
qf<- cbind(qf,temp[,3])
qf<- cbind(qf,temp[,4])
qf<- cbind(qf,temp[,5])
time <- cbind(time,temp[,1]/1000)

# Sum charges of all water molecules, collect in column 4
for (I in seq(5,54,1)) {
  for (j in seq(1,length(qf[,4]),1)) {
    qf[j,4] = qf[j,4] + temp[j,I+1]
  } 
}

png(filename = "Figure4b.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


ymax=1.3
ymin=-1.4
qfmax=max(qf)
qfmin=min(qf)
xmin=1
xmax=7

par(mar=c(4,5.5,1,2))
plot(time[,1],qf[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="")
lines(time[,1],qf[,2],type='l',lwd=5,col="red")
lines(time[,1],qf[,3],type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,4],type='l',lwd=5,col="blue")
lines(time[,1],qf[,2]+qf[,3],lty=2,type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,1]+qf[,2]+qf[,3]+qf[,4],lty=2,type='l',lwd=5,col="black")

axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
text(x=5.0,y=0.5*ymin,bquote("CU2, 50 eV electron"),cex=1.75)
title(xlab="Time (fs)", cex.lab=1.75,line=2)
title(ylab="charge variation (a.u.)",cex.lab=1.75,line=4)



dev.off()


############################# PLOT CHARGE FLUCTUATIONS I3 = CS ###############################
# Read data

time<-c()
qf<-c()
temp <- data.frame(read.table(file='I3/USPEl_QFDiff_I3_K5-5_1_FR1_54.dat',header=FALSE))
qf<- cbind(qf,temp[,2])
qf<- cbind(qf,temp[,3])
qf<- cbind(qf,temp[,4])
qf<- cbind(qf,temp[,5])
time <- cbind(time,temp[,1]/1000)

# Sum charges of all water molecules, collect in column 4
for (I in seq(5,54,1)) {
  for (j in seq(1,length(qf[,4]),1)) {
    qf[j,4] = qf[j,4] + temp[j,I+1]
  } 
}
qf[500,1]+qf[500,2]+qf[500,3]

png(filename = "Figure4c.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


ymax=0.7
ymin=-0.5
qfmax=max(qf)
qfmin=min(qf)
xmin=1
xmax=7

par(mar=c(4,5.5,1,2))
plot(time[,1],qf[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="")
lines(time[,1],qf[,2],type='l',lwd=5,col="red")
lines(time[,1],qf[,3],type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,4],type='l',lwd=5,col="blue")
lines(time[,1],qf[,2]+qf[,3],lty=2,type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,1]+qf[,2]+qf[,3]+qf[,4],lty=2,type='l',lwd=5,col="black")

axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
text(x=5.0,y=0.5*ymin,bquote("CS, 50 eV electron"),cex=1.75)
title(xlab="Time (fs)", cex.lab=1.75,line=2)
title(ylab="charge variation (a.u.)",cex.lab=1.75,line=4)

dev.off()

############################# PLOT CHARGE FLUCTUATIONS I4 = CP ###############################
# Read data

time<-c()
qf<-c()
temp <- data.frame(read.table(file='I4/USPEl_QFDiff_I4_K5-5_1_FR1_54.dat',header=FALSE))
qf<- cbind(qf,temp[,2])
qf<- cbind(qf,temp[,3])
qf<- cbind(qf,temp[,4])
qf<- cbind(qf,temp[,5])
time <- cbind(time,temp[,1]/1000)

# Sum charges of all 51 water molecules, collect in column 4
for (I in seq(5,54,1)) {
  for (j in seq(1,length(qf[,4])-1,1)) {
    qf[j,4] = qf[j,4] + temp[j,I+1]
  } 
}


png(filename = "Figure4d.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


ymax=1.0
ymin=-.8
qfmax=max(qf)
qfmin=min(qf)
xmin=1
xmax=7

par(mar=c(4,5.5,1,2))
plot(time[,1],qf[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="")
lines(time[,1],qf[,2],type='l',lwd=5,col="red")
lines(time[,1],qf[,3],type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,4],type='l',lwd=5,col="blue")
lines(time[,1],qf[,2]+qf[,3],lty=2,type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,1]+qf[,2]+qf[,3]+qf[,4],lty=2,type='l',lwd=5,col="black")

axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
text(x=5.0,y=0.5*ymin,bquote("CP, 50 eV electron"),cex=1.75)
title(xlab="Time (fs)", cex.lab=1.75,line=2)
title(ylab="charge variation (a.u.)",cex.lab=1.75,line=4)

dev.off()


############################# PLOT CHARGE FLUCTUATIONS I5 = CW ###############################
# Read data

time<-c()
qf<-c()
temp <- data.frame(read.table(file='I5/USPEl_QFDiff_I5_K5-5_1_FR1_54.dat',header=FALSE))
qf<- cbind(qf,temp[,2])
qf<- cbind(qf,temp[,3])
qf<- cbind(qf,temp[,4])
qf<- cbind(qf,temp[,5])

for (I in seq(4,54,1)) {
  qf<- cbind(qf,temp[,I+1])
}
time <- cbind(time,temp[,1]/1000)

# Sum charges of all water molecules but water number 21, 33 and 39, collect in column 55
qf<- cbind(qf,temp[,4])
for (I in seq(5,54,1)) {
  if (I != 22 && I != 34 && I != 40 ) {
    for (j in seq(1,length(qf[,4])-1,1)) {
      qf[j,55] = qf[j,55] + temp[j,I]
    }
  }
}


png(filename = "Figure4e.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )


ymax=1.5
ymin=-2.2
qfmax=max(qf)
qfmin=min(qf)
xmin=1
xmax=7
par(mar=c(4,5.5,1,2))
plot(time[,1],qf[,1],xlim=c(xmin,xmax),xaxs="i",ylim=c(ymin,ymax),type='l',lwd=5,col="darkorange",
     axes=FALSE,xlab="",ylab="")
lines(time[,1],qf[,2],type='l',lwd=5,col="red")
lines(time[,1],qf[,3],type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,55],type='l',lwd=5,col="blue")
lines(time[,1],qf[,22],type='l',lty=4,lwd=5,col="darkblue")
lines(time[,1],qf[,34],type='l',lty=4,lwd=5,col="darkblue")
lines(time[,1],qf[,40],type='l',lty=4,lwd=5,col="darkblue")
lines(time[,1],qf[,2]+qf[,3],lty=2,type='l',lwd=5,col="forestgreen")
lines(time[,1],qf[,1]+qf[,2]+qf[,3]+qf[,55]+qf[,22]+qf[,34]+qf[,40],lty=2,type='l',lwd=5,col="black")

axis(1,at=seq(xmin,xmax,0.5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
text(x=5.0,y=0.5*ymin,bquote("CW, 50 eV electron"),cex=1.75)
title(xlab="Time (fs)", cex.lab=1.75,line=2)
title(ylab="charge variation (a.u.)",cex.lab=1.75,line=4)

dev.off()

