
#INPUT FILES:
#Ix/USPHe_EMOL_Ix_K-1_1.dat : contains 3 columns, time [in attosecond], Energy of the molecule [in hartree], deposited energy [in eV]
#Ix/xUSPHe_QFDiff_Ix_K-1_1_FR1_54.dat: contains 56 columns, time [in attosecond], charge of each of the 54 molecular fragments composing the QM region. (Phosphate, ribose, base, 51 water molecules)

#OUTPUT FILES:
#FigureS1left.tiff, Image of the deposition energy profile (Figure S1)
#Figure3a-to-e.tiff, Image of charge fluctuations (Figure S3)

#VARIABLES
qfu <-c()  # Time series containing charge difference on uracil
qfs <-c()  # Time series containing charge difference on sugar
qfp <-c()  # Time series containing charge difference on phosphate
qfw <-c()  # Time series containing charge difference on water shell
time <-c() # Time series containing time, converted in femtoseconds 
# ID Identifies each of the eleven electron dynamics simulations. 


#CONVERSION FACTORS
ua2D=2.54174629656520
ev2cm1=8065.73
ev2ha=0.0367502
kcalmol2ua=0.00159362
kcalmol2ev=0.0433634
fs2at=41.34137335
ha2cm=219474.63
j2eV=6.24181e18
bohr=5.2917721092*1E-11
uatps=2.418884326505*1E-17

# CONSTANTS  
kb=1.3806488e-23
temp=298.
hbar=1.054571726E-34
kbTeV=kb*temp*j2eV
kbTha=kbTeV*ev2ha
clum=299792458*uatps/bohr


############################# PLOT CHARGE FLUCTUATIONS CU1 ###############################
# Read data
time <-c()
qfu <-c()
qfs <-c()
qfp <-c()
qfw <-c()
for (ID in c(375,500,625,750,875,1000,1125,1750,1875,2000,2125)) {
  temp <- data.frame(read.table(file=paste('I',ID,'/USPHeCU1_QFDiff_I',ID,'_K-1_1_FR1_64.dat',sep=""),header=FALSE))
  qfu<- cbind(qfu,temp[,4])
  qfs<- cbind(qfs,temp[,3])
  qfp<- cbind(qfp,temp[,2])
  time<-c()
  time <- cbind(time,temp[,1]/1000)

# Sum charges of all water molecules, collect in column 4
  for (I in seq(6,65,1)) {
    temp[1:length(qfu[,1]),5] = temp[1:length(qfu[,1]),5] + temp[1:length(qfu[,1]),I]
  }
  qfw<- cbind(qfw,temp[,5])
}

# Calculate average curves, putting results in last column
avg <- c()
for (j in seq(1,length(qfu[,1]),1)) {
  avg <- rbind(avg,mean(qfu[j,]))
}
qfu <- cbind(qfu,avg)

avg <- c()
for (j in seq(1,length(qfs[,1]),1)) {
  avg <- rbind(avg,mean(qfs[j,]))
}
qfs <- cbind(qfs,avg)

avg <- c()
for (j in seq(1,length(qfp[,1]),1)) {
  avg <- rbind(avg,mean(qfp[j,]))
}
qfp <- cbind(qfp,avg)

avg <- c()
for (j in seq(1,length(qfw[,1]),1)) {
  avg <- rbind(avg,mean(qfw[j,]))
}
qfw <- cbind(qfw,avg)


# Make plots of charge differences for U, S, P and W

first=400
last=1440
tiff(filename = "FigureS2Left_U.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )


ymax=signif(max(qfu),2)
ymin=signif(min(qfu),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfu[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="forestgreen",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfu[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="forestgreen")
}
lines(time[first:last],qfu[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU1 0.1 MeV alpha particle, U",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)

dev.off()


tiff(filename = "FigureS2Left_US.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfu+qfs),2)
ymin=signif(min(qfu+qfs),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfu[first:last,1]+qfs[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lty=2,lwd=2,col="forestgreen",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfu[first:last,i]+qfs[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lty=2,lwd=2,col="forestgreen")
}
lines(time[first:last],qfu[first:last,12]+qfs[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lty=2,lwd=3,col="black")
axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(ymin,ymax,0.5),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU1 0.1 MeV alpha particle, U+S",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)

dev.off()


tiff(filename = "FigureS2Left_S.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfs),2)
ymin=signif(min(qfs),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfs[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="red",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfs[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="red")
}
lines(time[first:last],qfs[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU1 0.1 MeV alpha particle, S",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)


dev.off()



tiff(filename = "FigureS2Left_P.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfp),2)
ymin=signif(min(qfp),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfp[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="darkorange",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfp[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="darkorange")
}
lines(time[first:last],qfp[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/50.,2)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU1 0.1 MeV alpha particle, P",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)



dev.off()




tiff(filename = "FigureS2Left_W.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=1.2
ymin=-1.4
qfmax=max(qfw)
qfmin=min(qfw)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfw[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="blue",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfw[first:last,i],type="l",lwd=2,col="blue")
}
lines(time[first:last],qfw[first:last,12],type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU1 0.1 MeV alpha particle, Water shell",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)


dev.off()



############################# PLOT CHARGE FLUCTUATIONS CU2 ###############################""
# Read data
time <-c()
qfu <-c()
qfs <-c()
qfp <-c()
qfw <-c()
for (ID in c(375,500,625,750,875,1000,1125,1750,1875,2000,2125)) {
  temp <- data.frame(read.table(file=paste('I',ID,'/USPHeCU2_QFDiff_I',ID,'_K-1_1_FR1_64.dat',sep=""),header=FALSE))
  qfu<- cbind(qfu,temp[,4])
  qfs<- cbind(qfs,temp[,3])
  qfp<- cbind(qfp,temp[,2])
  time<-c()
  time <- cbind(time,temp[,1]/1000)
  
  # Sum charges of all water molecules, collect in column 4
  for (I in seq(6,65,1)) {
    temp[1:length(qfu[,1]),5] = temp[1:length(qfu[,1]),5] + temp[1:length(qfu[,1]),I]
  }
  qfw<- cbind(qfw,temp[,5])
}

# Calculate average curves, putting results in last column
avg <- c()
for (j in seq(1,length(qfu[,1]),1)) {
  avg <- rbind(avg,mean(qfu[j,]))
}
qfu <- cbind(qfu,avg)

avg <- c()
for (j in seq(1,length(qfs[,1]),1)) {
  avg <- rbind(avg,mean(qfs[j,]))
}
qfs <- cbind(qfs,avg)

avg <- c()
for (j in seq(1,length(qfp[,1]),1)) {
  avg <- rbind(avg,mean(qfp[j,]))
}
qfp <- cbind(qfp,avg)

avg <- c()
for (j in seq(1,length(qfw[,1]),1)) {
  avg <- rbind(avg,mean(qfw[j,]))
}
qfw <- cbind(qfw,avg)


# Make plots of charge differences for U, S, P and W

first=400
last=1440
tiff(filename = "FigureS2Right_U.tiff",
     width = 1500, height = 1200, units = "px", pointsize = 30,
     bg = "white",  res = NA,
     type = c("cairo", "Xlib", "quartz") )


ymax=signif(max(qfu),2)
ymin=signif(min(qfu),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfu[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="forestgreen",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfu[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="forestgreen")
}
lines(time[first:last],qfu[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU2 0.1 MeV alpha particle, U",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)

dev.off()


tiff(filename = "FigureS2Right_US.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfu+qfs),2)
ymin=signif(min(qfu+qfs),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfu[first:last,1]+qfs[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lty=2,lwd=2,col="forestgreen",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfu[first:last,i]+qfs[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lty=2,lwd=2,col="forestgreen")
}
lines(time[first:last],qfu[first:last,12]+qfs[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lty=2,lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU2 0.1 MeV alpha particle, U+S",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)

dev.off()


tiff(filename = "FigureS2Right_S.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfs),2)
ymin=signif(min(qfs),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfs[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="red",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfs[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="red")
}
lines(time[first:last],qfs[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU2 0.1 MeV alpha particle, S",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)


dev.off()



tiff(filename = "FigureS2Right_P.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=max(qfp)
ymin=min(qfp)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfp[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",
     lwd=2,col="darkorange",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfp[first:last,i],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="darkorange")
}
lines(time[first:last],qfp[first:last,12],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/50.,2)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU2 0.1 MeV alpha particle, P",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)
dev.off()


tiff(filename = "FigureS2Right_W.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

ymax=signif(max(qfw),2)
ymin=signif(min(qfw),2)
xmin=2
xmax=7.5

par(mar=c(5.5,5.5,2,2))
plot(time[first:last],qfw[first:last,1],xlim=c(xmin,xmax),ylim=c(ymin,ymax),type="l",lwd=2,col="blue",axes=FALSE,xlab="",ylab="")
for (i in seq(2,11,1)) {
  lines(time[first:last],qfw[first:last,i],type="l",lwd=2,col="blue")
}
lines(time[first:last],qfw[first:last,12],type="l",lwd=3,col="black")

yami=floor(ymin)
yama=ceiling(ymax)
ytk=round((yama-yami)/10.,1)

axis(1,at=seq(xmin,xmax,1),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(yami,yama,ytk),pos=xmin,cex.axis=1.75,lwd=2,las=1)
title(main="CU2 0.1 MeV alpha particle, Water shell",cex.main=1.75,line=-0.5)
title(xlab="Time (fs)",
      ylab="charge variation (a.u.)",cex.lab=1.75,line=3)


dev.off()

